@@ -85,6 +85,7 @@ typedef struct _Filesel {
         GtkWidget *chooser;             /* Filechooser widget */
         GtkWidget *space;               /* Space available */
         GtkWidget *info;                /* File info */
+        Preview *preview;		/* Selected file preview */
 	GtkFileFilter *filter[FILESEL_MAX_FILTERS];	
 
 	/* State. 
@@ -94,7 +95,6 @@ typedef struct _Filesel {
 	gboolean save;			/* True if this is a save dialog */
 	gboolean multi;			/* Multiple-select */
 	gboolean start_name;		/* True if we have a suggested name */
-	struct _Browse *browse;		/* Browse window */
 
 	FileselFileType **type;		/* Allowable types for this filesel */
 	int ntypes;
