@@ -74,7 +74,7 @@ struct _iImage {
 
 	/* Private ... build iobject caption here.
 	 */
-	BufInfo caption_buffer;
+	VipsBuf caption_buffer;
 };
 
 typedef struct _iImageClass {
