@@ -138,10 +138,9 @@ imageview_refresh_title( Imageview *iv )
 		Conversion *conv = imagemodel->conv;
 		Imageinfo *ii = iimage->value.ii;
 
-		VipsBuf buf;
 		char txt[512];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-		vips_buf_init_static( &buf, txt, 512 );
 		row_qualified_name_relative( ws->sym, row, &buf );
 
 		if( ii && imageinfo_is_from_file( ii ) )
@@ -247,13 +246,12 @@ imageview_new_arrow2_action_cb( GtkAction *action, Imageview *iv )
 	int dy = imagemodel->visible.top + imagemodel->visible.height / 2;
 
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	Symbol *sym;
 	int ix, iy;
 
 	conversion_disp_to_im( conv, dx, dy, &ix, &iy );
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	vips_buf_appendf( &buf, "%s ", imageview_region_name[rt] );
 	row_qualified_name_relative( ws->sym, row, &buf );
 	switch( rt ) {
@@ -274,7 +272,7 @@ imageview_new_arrow2_action_cb( GtkAction *action, Imageview *iv )
 	}
 
 	if( !(sym = workspace_add_def( ws, vips_buf_all( &buf ) )) ) {
-		box_alert( GTK_WIDGET( iv ) );
+		iwindow_alert( GTK_WIDGET( iv ), GTK_MESSAGE_ERROR );
 		return;
 	}
 
@@ -293,7 +291,7 @@ imageview_new_arrow4_action_cb( GtkAction *action, Imageview *iv )
 
 	Rect dr, ir;
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	Symbol *sym;
 	Column *col;
 
@@ -303,14 +301,13 @@ imageview_new_arrow4_action_cb( GtkAction *action, Imageview *iv )
 	dr.height = imagemodel->visible.height / 2;
 	conversion_disp_to_im_rect( conv, &dr, &ir );
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	vips_buf_appendf( &buf, "%s ", imageview_region_name[rt] );
 	row_qualified_name_relative( ws->sym, row, &buf );
 	vips_buf_appendf( &buf, " (%d) (%d) %d %d", 
 		ir.left, ir.top, ir.width, ir.height );
 
 	if( !(sym = workspace_add_def( ws, vips_buf_all( &buf ) )) ) {
-		box_alert( GTK_WIDGET( iv ) );
+		iwindow_alert( GTK_WIDGET( iv ), GTK_MESSAGE_ERROR );
 		return;
 	}
 
@@ -346,7 +343,7 @@ imageview_recalc_action_cb( GtkAction *action, Imageview *iv )
         workspace_deselect_all( row->ws );
         row_select( row );
         if( !workspace_selected_recalc( row->ws ) )
-                box_alert( GTK_WIDGET( iv ) );
+		iwindow_alert( GTK_WIDGET( iv ), GTK_MESSAGE_ERROR );
         workspace_deselect_all( row->ws );
 }
 
@@ -357,10 +354,9 @@ imageview_header_action_cb( GtkAction *action, Imageview *iv )
 	iImage *iimage = imagemodel->iimage;
 	Row *row = HEAPMODEL( iimage )->row;
 	Workspace *ws = row_get_workspace( row );
-	VipsBuf buf;
 	char txt[512];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 512 );
 	row_qualified_name_relative( ws->sym, row, &buf );
 	conversion_header_dialog( imagemodel->conv, 
 		vips_buf_all( &buf ), GTK_WIDGET( iv ) );
@@ -760,6 +756,12 @@ imageview_build( Imageview *iv, GtkWidget *vbox, iImage *iimage )
 	gtk_box_pack_start( GTK_BOX( vbox ), mbar, FALSE, FALSE, 0 );
         gtk_widget_show( mbar );
 
+	/* This will set to NULL if we don't have infobar support.
+	 */
+	if( (IWINDOW( iv )->infobar = infobar_new()) ) 
+		gtk_box_pack_start( GTK_BOX( vbox ), 
+			GTK_WIDGET( IWINDOW( iv )->infobar ), FALSE, FALSE, 0 );
+
 	/* Status bar.
 	 */
 	iv->sv = statusview_new( iv->imagemodel );
