@@ -247,10 +247,9 @@ program_refresh_kit( Toolkit *kit, Program *program, GtkTreePath *path )
 static void
 program_title( Program *program )
 {
-	VipsBuf buf;
 	char txt[512];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 512 );
 	if( program->kit && FILEMODEL( program->kit )->modified ) 
 		vips_buf_appendf( &buf, "*" ); 
 	vips_buf_appends( &buf, IOBJECT( program->kitg )->name );
@@ -457,19 +456,19 @@ program_find_note( Program *program, Symbol *sym, int start, int end )
 static gboolean
 program_find_pos( Program *program, const char *text, int *start, int *end )
 {
-#ifdef HAVE_REGEXEC
+#ifdef HAVE_GREGEX
 	if( program->regexp ) {
-		regmatch_t matches[1];
-
-		if( !regexec( program->comp, text, 1, matches, 0 ) ) {
-			*start = matches[0].rm_so;
-			*end = matches[0].rm_eo;
+		GMatchInfo *match;
 
+		g_regex_match( program->comp, text, 0, &match );
+		if( g_match_info_fetch_pos( match, 0, start, end ) ) {
+			g_match_info_free( match );
 			return( TRUE );
 		}
+		g_match_info_free( match );
 	}
 	else 
-#endif /*HAVE_REGEXEC*/
+#endif /*HAVE_GREGEX*/
 	if( program->csens ) {
 		char *p;
 
@@ -575,9 +574,9 @@ program_destroy( GtkObject *object )
 	FREESID( program->kitgroup_destroy_sid, program->kitg );
 
 	IM_FREEF( g_free, program->search );
-#ifdef HAVE_REGEXEC
-	IM_FREEF( regfree, program->comp );
-#endif /*HAVE_REGEXEC*/
+#ifdef HAVE_GREGEX
+	IM_FREEF( g_regex_unref, program->comp );
+#endif /*HAVE_GREGEX*/
 
 	program_find_reset( program );
 
@@ -678,7 +677,8 @@ program_save_object_cb( GtkWidget *menu, Program *program )
 			filemodel_inter_save( IWINDOW( program ), 
 				FILEMODEL( model ) );
 		else 
-			box_alert( GTK_WIDGET( program ) );
+			iwindow_alert( GTK_WIDGET( program ), 
+				GTK_MESSAGE_ERROR );
 	}
 }
 
@@ -692,7 +692,8 @@ program_saveas_object_cb( GtkWidget *menu, Program *program )
 			filemodel_inter_saveas( IWINDOW( program ), 
 				FILEMODEL( model ) );
 		else
-			box_alert( GTK_WIDGET( program ) );
+			iwindow_alert( GTK_WIDGET( program ), 
+				GTK_MESSAGE_ERROR );
 	}
 }
 
@@ -786,11 +787,11 @@ program_init( Program *program )
 
 	program->search = NULL;
 	program->csens = FALSE;
-	program->regexp = FALSE;
 	program->fromtop = TRUE;
-#ifdef HAVE_REGEXEC
+#ifdef HAVE_GREGEX
+	program->regexp = FALSE;
 	program->comp = NULL;
-#endif /*HAVE_REGEXEC*/
+#endif /*HAVE_GREGEX*/
 }
 
 GtkType
@@ -850,8 +851,8 @@ program_set_text( Program *program, const char *text, gboolean editable )
 static void
 program_set_text_tool( Program *program, Tool *tool )
 {
-	char str[MAX_STRSIZE];
-	VipsBuf buf;
+	char txt[MAX_STRSIZE];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	switch( tool->type ) {
 	case TOOL_DIA:
@@ -862,15 +863,15 @@ program_set_text_tool( Program *program, Tool *tool )
 	case TOOL_SYM:
 		switch( tool->sym->type ) {
 		case SYM_EXTERNAL:
-			vips_buf_init_static( &buf, str, MAX_STRSIZE );
 			vips_usage( &buf, tool->sym->function );
-			program_set_text( program, vips_buf_all( &buf ), FALSE );
+			program_set_text( program, 
+				vips_buf_all( &buf ), FALSE );
 			break;
 
 		case SYM_BUILTIN:
-			vips_buf_init_static( &buf, str, MAX_STRSIZE );
 			builtin_usage( &buf, tool->sym->builtin );
-			program_set_text( program, vips_buf_all( &buf ), FALSE );
+			program_set_text( program, 
+				vips_buf_all( &buf ), FALSE );
 			break;
 
 		case SYM_VALUE:
@@ -1036,7 +1037,7 @@ program_tool_new_action_cb( GtkAction *action, Program *program )
 	/* Existing text changed? Parse it.
 	 */
 	if( program->dirty && !program_parse( program ) ) {
-		box_alert( GTK_WIDGET( program ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_ERROR );
 		return;
 	}
 
@@ -1053,8 +1054,8 @@ program_toolkit_new_done_cb( iWindow *iwnd, void *client,
 	Program *program = PROGRAM( client );
 
 	Toolkit *kit;
-	VipsBuf buf;
-	char str[1024];
+	char txt[1024];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	char name_text[1024];
 	char caption_text[1024];
 
@@ -1066,7 +1067,6 @@ program_toolkit_new_done_cb( iWindow *iwnd, void *client,
 
 	/* Make a filename from the name ... user start directory.
 	 */
-	vips_buf_init_static( &buf, str, 1024 );
 	vips_buf_appendf( &buf, "$SAVEDIR" G_DIR_SEPARATOR_S 
 		"start" G_DIR_SEPARATOR_S "%s.def", 
 		name_text );
@@ -1108,9 +1108,9 @@ static gboolean
 program_check_kit( Program *program )
 {
 	if( !program->kit ) {
-		box_info( GTK_WIDGET( program ), 
-			_( "Nothing selected." ),
-			_( "No toolkit selected." ) );
+		error_top( _( "Nothing selected." ) );
+		error_sub( "%s", _( "No toolkit selected." ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
 		return( FALSE );
 	}
 
@@ -1271,7 +1271,7 @@ static void
 program_process_action_cb( GtkAction *action, Program *program )
 {
 	if( !program_parse( program ) )
-		box_alert( GTK_WIDGET( program ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_ERROR );
 }
 
 static void
@@ -1375,9 +1375,10 @@ program_remove_tool_action_cb( GtkAction *action, Program *program )
 
 	if( model && IS_TOOL( model ) )
 		model_check_destroy( GTK_WIDGET( program ), model );
-	else 
-		box_info( GTK_WIDGET( program ), 
-			_( "No tool selected" ), "%s", "" );
+	else {
+		error_top( _( "No tool selected" ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
+	}
 }
 
 static void
@@ -1401,29 +1402,29 @@ program_find_done_cb( iWindow *iwnd, void *client,
 	program->search = 
 		gtk_editable_get_chars( GTK_EDITABLE( find->search ), 0, -1 );
 	program->csens = GTK_TOGGLE_BUTTON( find->csens )->active;
-#ifdef HAVE_REGEXEC
-	program->regexp = GTK_TOGGLE_BUTTON( find->regexp )->active;
-#endif /*HAVE_REGEXEC*/
 	program->fromtop = GTK_TOGGLE_BUTTON( find->fromtop )->active;
 
-#ifdef HAVE_REGEXEC
-	if( program->regexp ) {
-		int flags = 0;
+#ifdef HAVE_GREGEX
+	program->regexp = GTK_TOGGLE_BUTTON( find->regexp )->active;
 
-		if( !program->comp )
-			program->comp = INEW( NULL, regex_t );
+	if( program->regexp ) {
+		GRegexCompileFlags cflags = 0;
+		GRegexMatchFlags mflags = 0;
 
 		if( !program->csens )
-			flags |= REG_ICASE;
+			cflags |= G_REGEX_CASELESS;
 
-		if( regcomp( program->comp, program->search, flags ) != 0 ) {
+		IM_FREEF( g_regex_unref, program->comp );
+
+		if( !(program->comp = g_regex_new( program->search, 
+			cflags, mflags, NULL )) ) {
 			error_top( _( "Parse error." ) );
 			error_sub( _( "Bad regular expression." ) );
 			nfn( sys, IWINDOW_ERROR );
 			return;
 		}
 	}
-#endif /*HAVE_REGEXEC*/
+#endif /*HAVE_GREGEX*/
 
 	if( program->fromtop )
 		program_find_reset( program );
@@ -1463,10 +1464,10 @@ program_find_action_cb( GtkAction *action, Program *program )
 	set_tooltip( FIND( find )->search, _( "Enter search string here" ) );
         gtk_toggle_button_set_active( 
 		GTK_TOGGLE_BUTTON( FIND( find )->csens ), program->csens );
-#ifdef HAVE_REGEXEC
+#ifdef HAVE_GREGEX
         gtk_toggle_button_set_active( 
 		GTK_TOGGLE_BUTTON( FIND( find )->regexp ), program->regexp );
-#endif /*HAVE_REGEXEC*/
+#endif /*HAVE_GREGEX*/
         gtk_toggle_button_set_active( 
 		GTK_TOGGLE_BUTTON( FIND( find )->fromtop ), program->fromtop );
 
@@ -1484,10 +1485,10 @@ program_find_again_action_cb( GtkAction *action, Program *program )
 		text_view_select_text( GTK_TEXT_VIEW( program->text ), 
 			program->find_start, program->find_end );
 	}
-	else
-		box_info( GTK_WIDGET( program ), 
-			_( "Not found." ),
-			_( "No match found." ) );
+	else {
+		error_top( _( "Not found." ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
+	}
 }
 
 static void
@@ -1565,13 +1566,13 @@ program_goto_action_cb( GtkAction *action, Program *program )
 static void
 program_info_action_cb( GtkAction *action, Program *program )
 {
-	VipsBuf buf;
 	char txt[MAX_STRSIZE];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	program_info( program, &buf );
-	box_info( GTK_WIDGET( program ), _( "Object information." ), 
-		"%s", vips_buf_all( &buf ) );
+	error_top( _( "Object information." ) );
+	error_sub( "%s", vips_buf_all( &buf ) );
+	iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
 }
 
 static void
@@ -1598,10 +1599,8 @@ program_errorreport_action_cb( GtkAction *action, Program *program )
 static void
 program_tool_help_action_cb( GtkAction *action, Program *program )
 {
-	VipsBuf buf;
 	char txt[512];
-
-	vips_buf_init_static( &buf, txt, 512 );
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	if( program->tool && program->tool->type == TOOL_SYM && 
 		program->kit && program->kit->pseudo ) {
@@ -1621,11 +1620,12 @@ program_tool_help_action_cb( GtkAction *action, Program *program )
 			break;
 		}
 	}
-	else
-		box_info( GTK_WIDGET( program ), 
-			_( "No documentation available." ),
-			_( "On-line documentation is only currently "
+	else {
+		error_top( _( "No documentation available." ) );
+		error_sub( "%s", _( "On-line documentation is only currently "
 			"available for VIPS functions and nip builtins." ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
+	}
 }
 
 /* Our actions.
@@ -1885,7 +1885,7 @@ program_select_row( Program *program, GtkTreeIter *iter )
 		model = MODEL( kit );
 
 	if( !program_select( program, model ) ) 
-		box_alert( GTK_WIDGET( program ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_ERROR );
 }
 
 static void
@@ -2025,11 +2025,12 @@ program_row_deleted_cb( GtkTreeModel *treemodel,
 #endif /*DEBUG*/
 
 	if( !program->to_kit || !program->tool ) {
-		box_info( GTK_WIDGET( program ), 
-			_( "Bad drag." ),
+		error_top( _( "Bad drag." ) );
+		error_sub( "%s", 
 			_( "Sorry, you can only drag tools between toolkits. "
 			"You can't reorder toolkits, you can't nest toolkits "
 			"and you can't drag tools to the top level." ) );
+		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
 		return;
 	}
 
@@ -2180,6 +2181,13 @@ program_build( Program *program, GtkWidget *vbox )
         gtk_signal_connect( GTK_OBJECT( item ), "map",
                 GTK_SIGNAL_FUNC( program_edit_map_cb ), program );
 
+	/* This will set to NULL if we don't have infobar support.
+	 */
+	if( (IWINDOW( program )->infobar = infobar_new()) ) 
+		gtk_box_pack_start( GTK_BOX( vbox ), 
+			GTK_WIDGET( IWINDOW( program )->infobar ), 
+			FALSE, FALSE, 0 );
+
 	program->pane = gtk_hpaned_new();
 	gtk_paned_set_position( GTK_PANED( program->pane ), 
 		program->pane_position );
