@@ -95,13 +95,13 @@ toolkit_changed( iObject *iobject )
 }
 
 static void
-toolkit_info( iObject *iobject, BufInfo *buf )
+toolkit_info( iObject *iobject, VipsBuf *buf )
 {
 	Toolkit *kit = TOOLKIT( iobject );
 
 	IOBJECT_CLASS( parent_class )->info( iobject, buf );
 
-	buf_appendf( buf, "group = \"%s\"\n", IOBJECT( kit->kitg )->name );
+	vips_buf_appendf( buf, "group = \"%s\"\n", IOBJECT( kit->kitg )->name );
 }
 
 static View *
@@ -140,8 +140,6 @@ toolkit_load_text( Model *model, Model *parent, iOpenFile *of )
 			FILEMODEL( kit )->filename, input_state.lineno, 
 			error_get_sub() );
 
-	iobject_changed( IOBJECT( kit ) );
-
 #ifdef DEBUG
 	(void) dump_kit( kit );
 #endif /*DEBUG*/
@@ -327,60 +325,3 @@ toolkit_by_name( Toolkitgroup *kitg, const char *name )
 
 	return( kit );
 }
-
-static void *
-toolkit_linkreport_sym_sym( Symbol *child, 
-	Symbol *parent, BufInfo *buf, gboolean *found )
-{
-	if( child->type == SYM_ZOMBIE && !compile_resolve_top( child ) ) {
-		Tool *tool = symbol_get_tool( parent );
-
-		symbol_qualified_name( parent, buf );
-		tool_error( tool, buf );
-
-		buf_appendf( buf, " " );
-		/* used as in "fred refers to undefined symbol jim"
-		 */
-		buf_appendf( buf, _( "refers to undefined symbol" ) );
-		buf_appendf( buf, " " );
-		symbol_qualified_name( child, buf );
-		buf_appendf( buf, "\n" );
-
-		*found = TRUE;
-	}
-
-	return( NULL );
-}
-
-static void *
-toolkit_linkreport_sym( Symbol *sym, BufInfo *buf, gboolean *found )
-{
-	if( sym->expr )
-		return( slist_map3( sym->expr->compile->children,
-			(SListMap3Fn) toolkit_linkreport_sym_sym, 
-			sym, buf, found ) );
-
-	return( NULL );
-}
-
-static void *
-toolkit_linkreport_tool( Tool *tool, BufInfo *buf, gboolean *found )
-{
-	Symbol *sym;
-
-	if( tool->type != TOOL_SYM )
-		return( NULL );
-	sym = tool->sym;
-
-	return( symbol_map_all( tool->sym, 
-		(symbol_map_fn) toolkit_linkreport_sym, buf, found ) );
-}
-
-void *
-toolkit_linkreport( Toolkit *kit, BufInfo *buf, gboolean *found )
-{
-	return( icontainer_map( ICONTAINER( kit ), 
-		(icontainer_map_fn) toolkit_linkreport_tool, buf, found ) );
-}
-
-
