@@ -51,6 +51,10 @@
  */
 #define MAX_VIPS_ARGS (100)
 
+/* Maximum length of a vector we pass to INTVEC etc.
+ */
+#define MAX_VEC (10000)
+
 /* Stuff we hold about a call to a VIPS function.
  */
 typedef struct _VipsInfo {
@@ -538,7 +542,7 @@ vips_history_sanity( void )
 		g_assert( g_hash_table_lookup( vips_history_table, vi ) );
 
 		g_assert( vi->fn );
-		g_assert( vi->fn->argc > 0 && vi->fn->argc < 100 );
+		g_assert( vi->fn->argc > 0 && vi->fn->argc < MAX_VIPS_ARGS );
 		g_assert( vi->in_cache );
 	}
 
@@ -730,7 +734,6 @@ vips_destroy( VipsInfo *vi )
 		case VIPS_DOUBLE:
 		case VIPS_INT: 	
 		case VIPS_COMPLEX: 
-		case VIPS_IMAGEVEC: 	/* Input only, so no freeing reqd */
 		case VIPS_GVALUE:
 		case VIPS_INTERPOLATE:
 			/* Do nothing.
@@ -752,6 +755,14 @@ vips_destroy( VipsInfo *vi )
 			}
 			break;
 
+		case VIPS_IMAGEVEC: 	
+			/* We only allow input IMAGEVEC, so we just need to
+			 * free the spine.
+			 */
+			g_assert( !(ty->flags & IM_TYPE_OUTPUT) );
+			IM_FREE( ((im_imagevec_object *) obj)->vec );
+			break;
+
 		case VIPS_DOUBLEVEC:
 			IM_FREE( ((im_doublevec_object *) obj)->vec );
 			break;
@@ -1068,12 +1079,11 @@ vips_usage( VipsBuf *buf, im_function *fn )
 static void
 vips_error_arg( VipsInfo *vi, HeapNode **arg, int argi )
 {
-	VipsBuf buf;
 	char txt[1000];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	error_top( _( "Bad argument." ) );
 
-	vips_buf_init_static( &buf, txt, 1000 );
 	vips_buf_appendf( &buf,
 		_( "Argument %d (%s) to \"%s\" is the wrong type." ),
 		argi + 1, vi->fn->argv[argi].name, vi->name );
@@ -1090,12 +1100,11 @@ vips_error_arg( VipsInfo *vi, HeapNode **arg, int argi )
 static void
 vips_error_fn_vips( VipsInfo *vi )
 {
-	VipsBuf buf;
 	char txt[1000];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	error_top( _( "VIPS library error." ) );
 
-	vips_buf_init_static( &buf, txt, 1000 );
 	vips_buf_appendf( &buf, 
 		_( "Error calling library function \"%s\" (%s)." ),
 		vi->name, vi->fn->desc );
@@ -1394,10 +1403,10 @@ vips_fromip( Reduce *rc, PElement *arg,
 
 	case VIPS_DOUBLEVEC:
 	{
-		double buf[100];
+		double buf[MAX_VEC];
 		int n;
 
-		n = reduce_get_realvec( rc, arg, buf, 100 );
+		n = reduce_get_realvec( rc, arg, buf, MAX_VEC );
 		if( vips_make_doublevec( *obj, n, buf ) )
 			return( FALSE );
 
@@ -1406,10 +1415,10 @@ vips_fromip( Reduce *rc, PElement *arg,
 
 	case VIPS_INTVEC:
 	{
-		double buf[100];
+		double buf[MAX_VEC];
 		int n;
 
-		n = reduce_get_realvec( rc, arg, buf, 100 );
+		n = reduce_get_realvec( rc, arg, buf, MAX_VEC );
 		if( vips_make_intvec( *obj, n, buf ) )
 			return( FALSE );
 
@@ -1418,13 +1427,13 @@ vips_fromip( Reduce *rc, PElement *arg,
 
 	case VIPS_IMAGEVEC:
 	{
-		Imageinfo *buf[100];
+		Imageinfo *buf[MAX_VEC];
 		int n;
 
 		/* Put Imageinfo in for now ... a later pass changes this to
 		 * IMAGE* once we've checked all the LUTs.
 		 */
-		n = reduce_get_imagevec( rc, arg, buf, 100 );
+		n = reduce_get_imagevec( rc, arg, buf, MAX_VEC );
 		if( vips_make_imagevec( *obj, n, (IMAGE **) buf ) )
 			return( FALSE );
 
@@ -1888,10 +1897,9 @@ vips_build_argv( VipsInfo *vi, char **argv )
 	int i;
 
 	for( i = 0; i < vi->fn->argc; i++ ) {
-		VipsBuf buf;
 		char txt[512];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-		vips_buf_init_static( &buf, txt, 512 );
 		vips_tobuf( vi, i, &buf );
 		if( !(argv[i] = im_strdup( NULL, vips_buf_all( &buf ) )) )
 			return( FALSE );
